==> libphidget22-1.0.0.20181105.tar.gz: libphidget22-1.0.0.20181105/src/errorstrings.gen.c <==
#include "errorstrings.gen.h"

const char * CCONV
Phidget_strerror(PhidgetReturnCode code) {

	switch (code) {
	case EPHIDGET_OK:
		return ("Success");
	case EPHIDGET_PERM:
		return ("Not Permitted");
	case EPHIDGET_NOENT:
		return ("No Such Entity");
	case EPHIDGET_TIMEOUT:
		return ("Timed Out. This can happen for a number of common reasons. Check that the Phidget you are trying to open is plugged in, and that the addressing parameters have been specified correctly. Check that the Phidget is not already open in another program, such as the Phidget Control Panel, or another program you are developing. If you are using remote Phidgets, ensure that your computer can access the remote Phidgets using the Phidget Control Panel. If you are using remote Phidgets, ensure you have enabled Server Discovery or added the server corresponding to the Phidget you are trying to open. If you are using Network Server Discovery, try extending the timeout to allow more time for the server to be discovered.");
	case EPHIDGET_KEEPALIVE:
		return ("Keep Alive Failure");
	case EPHIDGET_INTERRUPTED:
		return ("Op Interrupted");
	case EPHIDGET_IO:
		return ("IO Issue");
	case EPHIDGET_NOMEMORY:
		return ("Memory Issue");
	case EPHIDGET_ACCESS:
		return ("Access (Permission) Issue");
	case EPHIDGET_FAULT:
		return ("Address Issue");
	case EPHIDGET_BUSY:
		return ("Resource Busy");
	case EPHIDGET_EXIST:
		return ("Object Exists");
	case EPHIDGET_NOTDIR:
		return ("Object is not a directory");
	case EPHIDGET_ISDIR:
		return ("Object is a directory");
	case EPHIDGET_INVALID:
		return ("Invalid");
	case EPHIDGET_NFILE:
		return ("Too many open files in system");
	case EPHIDGET_MFILE:
		return ("Too many open files");
	case EPHIDGET_NOSPC:
		return ("Not enough space");
	case EPHIDGET_FBIG:
		return ("File too Big");
	case EPHIDGET_ROFS:
		return ("Read Only Filesystem");
	case EPHIDGET_RO:
		return ("Read Only Object");
	case EPHIDGET_UNSUPPORTED:
		return ("Operation Not Supported");
	case EPHIDGET_INVALIDARG:
		return ("Invalid Argument. One or more of the parameters passed to the function is not accepted by the channel in its current configuration. This may also be an indication that a NULL pointer was passed where a valid pointer is required.");
	case EPHIDGET_AGAIN:
		return ("Try again");
	case EPHIDGET_NOTEMPTY:
		return ("No Empty");
	case EPHIDGET_UNEXPECTED:
		return ("Unexpected Error");
	case EPHIDGET_DUPLICATE:
		return ("Duplicate");
	case EPHIDGET_BADPASSWORD:
		return ("Bad Credential");
	case EPHIDGET_NETUNAVAIL:
		return ("Network Unavailable");
	case EPHIDGET_CONNREF:
		return ("Connection Refused");
	case EPHIDGET_CONNRESET:
		return ("Connection Reset");
	case EPHIDGET_HOSTUNREACH:
		return ("No route to host");
	case EPHIDGET_NODEV:
		return ("No Such Device");
	case EPHIDGET_WRONGDEVICE:
		return ("Wrong Device");
	case EPHIDGET_PIPE:
		return ("Broken Pipe");
	case EPHIDGET_RESOLV:
		return ("Name Resolution Failure");
	case EPHIDGET_UNKNOWNVAL:
		return ("Unknown or Invalid Value");
	case EPHIDGET_NOTATTACHED:
		return ("Device Not Attached. This can happen for a number of common reasons. Be sure you are opening the channel before trying to use it. If you are opening the channel, the program may not be waiting for the channel to be attached. If possible use openWaitForAttachment. Otherwise, be sure to check the Attached property of the channel before trying to use it.");
	case EPHIDGET_INVALIDPACKET:
		return ("Invalid or Unexpected Packet");
	case EPHIDGET_2BIG:
		return ("Argument List Too Long");
	case EPHIDGET_BADVERSION:
		return ("Bad Version");
	case EPHIDGET_CLOSED:
		return ("Closed");
	case EPHIDGET_NOTCONFIGURED:
		return ("Not Configured");
	case EPHIDGET_EOF:
		return ("End of File");
	default:
		return ("Invalid return code");
	}
}

==> libphidget22-1.0.0.20190107.tar.gz: libphidget22-1.0.0.20190107/src/errorstrings.gen.c <==
#include "errorstrings.gen.h"

const char * CCONV
Phidget_strerror(PhidgetReturnCode code) {

	switch (code) {
	case EPHIDGET_OK:
		return ("Success");
	case EPHIDGET_PERM:
		return ("Not Permitted");
	case EPHIDGET_NOENT:
		return ("No Such Entity");
	case EPHIDGET_TIMEOUT:
		return ("Timed Out");
	case EPHIDGET_KEEPALIVE:
		return ("Keep Alive Failure");
	case EPHIDGET_INTERRUPTED:
		return ("Op Interrupted");
	case EPHIDGET_IO:
		return ("IO Issue");
	case EPHIDGET_NOMEMORY:
		return ("Memory Issue");
	case EPHIDGET_ACCESS:
		return ("Access (Permission) Issue");
	case EPHIDGET_FAULT:
		return ("Address Issue");
	case EPHIDGET_BUSY:
		return ("Resource Busy");
	case EPHIDGET_EXIST:
		return ("Object Exists");
	case EPHIDGET_NOTDIR:
		return ("Object is not a directory");
	case EPHIDGET_ISDIR:
		return ("Object is a directory");
	case EPHIDGET_INVALID:
		return ("Invalid");
	case EPHIDGET_NFILE:
		return ("Too many open files in system");
	case EPHIDGET_MFILE:
		return ("Too many open files");
	case EPHIDGET_NOSPC:
		return ("Not enough space");
	case EPHIDGET_FBIG:
		return ("File too Big");
	case EPHIDGET_ROFS:
		return ("Read Only Filesystem");
	case EPHIDGET_RO:
		return ("Read Only Object");
	case EPHIDGET_UNSUPPORTED:
		return ("Operation Not Supported");
	case EPHIDGET_INVALIDARG:
		return ("Invalid Argument");
	case EPHIDGET_AGAIN:
		return ("Try again");
	case EPHIDGET_NOTEMPTY:
		return ("Not Empty");
	case EPHIDGET_UNEXPECTED:
		return ("Unexpected Error");
	case EPHIDGET_DUPLICATE:
		return ("Duplicate");
	case EPHIDGET_BADPASSWORD:
		return ("Bad Credential");
	case EPHIDGET_NETUNAVAIL:
		return ("Network Unavailable");
	case EPHIDGET_CONNREF:
		return ("Connection Refused");
	case EPHIDGET_CONNRESET:
		return ("Connection Reset");
	case EPHIDGET_HOSTUNREACH:
		return ("No route to host");
	case EPHIDGET_NODEV:
		return ("No Such Device");
	case EPHIDGET_WRONGDEVICE:
		return ("Wrong Device");
	case EPHIDGET_PIPE:
		return ("Broken Pipe");
	case EPHIDGET_RESOLV:
		return ("Name Resolution Failure");
	case EPHIDGET_UNKNOWNVAL:
		return ("Unknown or Invalid Value");
	case EPHIDGET_NOTATTACHED:
		return ("Device not Attached");
	case EPHIDGET_INVALIDPACKET:
		return ("Invalid or Unexpected Packet");
	case EPHIDGET_2BIG:
		return ("Argument List Too Long");
	case EPHIDGET_BADVERSION:
		return ("Bad Version");
	case EPHIDGET_CLOSED:
		return ("Closed");
	case EPHIDGET_NOTCONFIGURED:
		return ("Not Configured");
	case EPHIDGET_EOF:
		return ("End of File");
	default:
		return ("Invalid return code");
	}
}
